# uncluster

[![GitHub][github_badge]][github_link] [![PyPI][pypi_badge]][pypi_link]

uncluster your remote folder!



## Installation

Install uncluster and its dependencies

```bash
git clone git@github.com:imyizhang/uncluster.git
pip install -e uncluster
```



## Quickstart

Set the environment variables

```bash
cd uncluster
cp .env.example .env
vim .env
```



Mirror your remote folder locally

```bash
uncluster -v
```



## License

uncluster has a MIT license, as found in the [LICENSE](https://github.com/imyizhang/uncluster/blob/main/LICENSE) file.



## Contributing

Thanks for your interest in contributing to uncluster! Please feel free to create a pull request.



## Changelog

**uncluster 0.0.1**

* First release



[github_badge]: https://badgen.net/badge/icon/GitHub?icon=github&color=black&label
[github_link]: https://github.com/imyizhang/uncluster



[pypi_badge]: https://badgen.net/pypi/v/uncluster?icon=pypi&color=black&label
[pypi_link]: https://www.pypi.org/project/uncluster